@@ -29,10 +29,7 @@ impl Backend for Git {
             .filter(|e| e.len() >= 2)
             .map(|e| {
                 let (status, filename) = e.split_at(2);
-                RevisionEntry {
-                    name: filename.trim().into(),
-                    status: parse_file_status(status.trim()),
-                }
+                RevisionEntry::new(filename.trim().into(), parse_file_status(status))
             })
             .collect();
 
@@ -71,7 +68,11 @@ impl Backend for Git {
                     args.push(&entry.name);
                 }
             }
-            let clean = Process::spawn("git", &args)?;
+            let clean = if args.len() > 3 {
+                Some(Process::spawn("git", &args)?)
+            } else {
+                None
+            };
 
             args.clear();
             args.push("rm");
@@ -82,10 +83,18 @@ impl Backend for Git {
                     args.push(&entry.name);
                 }
             }
-            let rm = Process::spawn("git", &args)?;
+            let rm = if args.len() > 3 {
+                Some(Process::spawn("git", &args)?)
+            } else {
+                None
+            };
 
-            clean.wait()?;
-            rm.wait()?;
+            if let Some(clean) = clean {
+                clean.wait()?;
+            }
+            if let Some(rm) = rm {
+                rm.wait()?;
+            }
 
             args.clear();
             args.push("checkout");
@@ -95,7 +104,9 @@ impl Backend for Git {
                     args.push(&entry.name);
                 }
             }
-            Process::spawn("git", &args)?.wait()?;
+            if args.len() > 2 {
+                Process::spawn("git", &args)?.wait()?;
+            }
         }
 
         Ok(())
@@ -281,7 +292,7 @@ impl Backend for Git {
         let message = message.wait()?.trim().into();
 
         let changes = changes.wait()?;
-        let mut splits = changes.split('\0').map(str::trim);
+        let mut splits = changes.split('\0');
 
         let mut entries = Vec::new();
         loop {
@@ -294,7 +305,7 @@ impl Backend for Git {
                 None => break,
             };
 
-            entries.push(RevisionEntry { name, status });
+            entries.push(RevisionEntry::new(name, status));
         }
 
         Ok(RevisionInfo { message, entries })
@@ -362,14 +373,15 @@ impl Backend for Git {
 }
 
 fn parse_file_status(s: &str) -> FileStatus {
-    match s {
-        "M" => FileStatus::Modified,
-        "A" => FileStatus::Added,
-        "D" => FileStatus::Deleted,
-        "R" => FileStatus::Renamed,
-        "??" => FileStatus::Untracked,
-        "C" => FileStatus::Copied,
-        "U" => FileStatus::Unmerged,
+    match s.chars().next() {
+        Some('M') => FileStatus::Modified,
+        Some('A') => FileStatus::Added,
+        Some('D') => FileStatus::Deleted,
+        Some('R') => FileStatus::Renamed,
+        Some('?') => FileStatus::Untracked,
+        Some('C') => FileStatus::Copied,
+        Some('U') => FileStatus::Unmerged,
+        Some(' ') => FileStatus::Clean,
         _ => panic!("unknown file status '{}'", s),
     }
 }
